Introduction
============

`Anticipatory action <https://centre.humdata.org/anticipatory-action/>`_
(AA) means shifting humanitarian response to be deployed ahead of a crisis.
Knowing when to provide humanitarian aid involves understanding the
risk that a potential shock may occur. Gaining this understanding often
requires in-depth analysis of decades of historical data relating to
the shock of interest as well as any related indicators.

This is where the AA Toolbox comes in. The goal of the toolbox is to to
support development of AA frameworks by simplifying the downloading and
processing of commonly used datasets.

Datasets currently supported are:

- CHIRPS rainfall
- COD ABs (Common Operational Datasets administrative boundaries)
- FEWS NET food insecurity
- GloFAS river discharge
- IRI seasonal rainfall forecast
- USGS NDVI (normalized difference vegetation index)

At the `Centre for Humanitarian Data <https://centre.humdata.org/>`_,
we've now used AA Toolbox to develop
some of our own AA frameworks. See the links below for more info:

* `Drought in Burkina Faso <https://github.com/OCHA-DAP/pa-aa-bfa-drought>`_
* `Cholera in DRC <https://github.com/OCHA-DAP/pa-aa-cod-infectious-disease>`_
  (this repository is private, please `contact us <mailto:centrehumdata@un.org>`_
  if you would like more information)
